// renderer.js

import electron from 'electron'
import { ipcRenderer, clipboard, shell } from 'electron'
import { sHomeUrlWorkflowy, sHomeUrlDynalist, sHomeUrlBlank } from '../main/constValues'

let iZoom = 10
let sHomeUrl = sHomeUrlBlank

let main_webview = document.createElement('webview')
main_webview.setAttribute( 'id', 'main_webview' )
main_webview.setAttribute( 'autosize', 'on' )
main_webview.setAttribute( 'minheight', '100' )
main_webview.setAttribute( 'src', sHomeUrl )
document.getElementById('main_area').appendChild( main_webview )


let textfield = document.createElement( 'footer' )
textfield.setAttribute( 'id', 'textfield' )
document.getElementById('main_area').appendChild( textfield )

let inputarea = document.createElement('input')
inputarea.setAttribute( 'type', 'text' )
inputarea.setAttribute( 'id', 'inputarea' )
inputarea.setAttribute( 'readOnly', 'true' )
document.getElementById('textfield').appendChild( inputarea )

let btn01 = document.createElement('input')
btn01.setAttribute( 'type', 'button' )
btn01.setAttribute( 'id', 'btn01' )
btn01.setAttribute( 'value', 'O.K.' )
document.getElementById('textfield').appendChild( btn01 );
document.querySelector('#btn01').addEventListener('click', function(){
  console.log("button clicked! clear TextArea.")
  inputarea.setAttribute( 'readOnly', 'true' )
  inputarea.value = ''
  textfield.style.display='none'
})

textfield.style.display='none'

function viewTextArea ( str, flg ){
  inputarea.value = str
  inputarea.setAttribute( 'readOnly', flg )
  textfield.style.display='block'
}


ipcRenderer.on('VIEW_VERSION', function(event, arg){
  //console.log("Ver."+arg)
  viewTextArea( "jsCBrowser is Simple Browser for Workflowy.  Ver."+arg, 'true' )
})

ipcRenderer.on('GO_HOME', function(event, arg){
    //console.log(arg)
    main_webview.loadURL(sHomeUrl)
})

ipcRenderer.on('GO_FORWARD', function(event, arg){
    //console.log(arg)
    if(main_webview.canGoForward()){ main_webview.goForward() }
})

ipcRenderer.on('GO_BACK', function(event, arg){
    //console.log(arg)
    if(main_webview.canGoBack()){ main_webview.goBack() }
})

ipcRenderer.on('GET_URL', function(event, arg){
  //console.log(arg)
  let sUrl = main_webview.getURL()
  viewTextArea( sUrl, 'true' )
  clipboard.writeText(sUrl)
  console.log(sUrl)
})


function zoomAction( iz ){
    if( iz < 5 ){ iZoom = 5 }
    if( iz > 30 ){ iZoom = 30 }
    if( (iz >= 5) && ( iz <= 30 )){ iZoom = iz }
    main_webview.setZoomFactor( iZoom/10 )
}

ipcRenderer.on('ZOOM_100', function(event, arg){
    iZoom = arg
    iZoom = 10
    zoomAction( iZoom )
    ipcRenderer.send('SEND_RENDER_ZOOM', iZoom)
})

ipcRenderer.on('ZOOM_IN', function(event, arg){
    iZoom = arg
    iZoom = iZoom + 1
    zoomAction( iZoom )
    ipcRenderer.send('SEND_RENDER_ZOOM', iZoom)
})

ipcRenderer.on('ZOOM_OUT', function(event, arg){
    iZoom = arg
    iZoom = iZoom - 1
    zoomAction( iZoom )
    ipcRenderer.send('SEND_RENDER_ZOOM', iZoom)
})


ipcRenderer.on('SET_BOLD', function(event, arg){
  main_webview.sendInputEvent({
    keyCode: 'b',
    type: 'keyDown',
    modifiers: ['control'],
  })
})

ipcRenderer.on('SET_ITALIC', function(event, arg){
  main_webview.sendInputEvent({
    type: 'keyDown',
    keyCode: 'i',
    modifiers: ['control'],
  })
})

ipcRenderer.on('SET_UNDERLINE', function(event, arg){
  main_webview.sendInputEvent({
    type: 'keyDown',
    keyCode: 'u',
    modifiers: ['control'],
  })
})

ipcRenderer.on('SEND_JSON_ZOOM', function(event, arg){
    iZoom = arg
})

ipcRenderer.on('IMPORT_PASTE', function(event, arg){
  //console.log(clipboard.readText())
  main_webview.paste() // dynalistだとうまく動作しない。
})

ipcRenderer.on('EXPORT', function(event, arg){
  let jscmd = 'document.getElementsByClassName("selected")[0].innerText'
  if(arg === 'export-dl'){
    jscmd = 'document.getElementsByClassName("is-currentRoot")[0].innerText'
  }
  main_webview.executeJavaScript(
    jscmd,
    function(res) {
      ipcRenderer.send('EXPORT_RETURN', res)
    })
})

ipcRenderer.on('STR_LEN', function(event, arg){
  let jscmd = 'document.getElementsByClassName("selected")[0].innerText'
  if(arg === 'export-dl'){
    jscmd = 'document.getElementsByClassName("is-currentRoot")[0].innerText'
  }
  main_webview.executeJavaScript(
    jscmd,
    function(res) {
      let line = res.split(/\r\n|\r|\n/)
      let chgTxt = line.join('')
      viewTextArea( chgTxt.length+'文字', 'true' )
    })
})

//ipcRenderer.on('EXPORT_FROM_WINDOW', function(event, arg){
//  main_webview.executeJavaScript(
//    '{text: window.getSelection().toString()}',
//    function(res) {
//      ipcRenderer.send('EXPORT_FROM_WINDOW_RETURN', res)
//    })
//})

ipcRenderer.on('SET_HOME_URL', function(event ,arg){
  console.log( 'renderer url ' + arg )
  if( arg != sHomeUrl ){
    sHomeUrl = arg
    main_webview.loadURL(sHomeUrl)
  }
})

main_webview.addEventListener('did-start-loading', function(){
  // こちらは初回起動時にも発火する
  // var sUrl = main_webview.getURL()
  // console.log('did-start-loading ' + sUrl )
})

main_webview.addEventListener('new-window', function( event ){
  // console.log('new-window ' + event.url )
  // workflowy上でLinkをクリックすると新しいウインドウでOpenされるので
  // デフォルトブラウザで起動するようにする
  if( /^https?\:\/\//.test(event.url) ){
    shell.openExternal(event.url)
  }
})

main_webview.addEventListener('did-navigate', function(){
  if(sHomeUrl===sHomeUrlBlank){
    // 起動後、webviewの準備完了したら合図を送る
    ipcRenderer.send('SEND_DID_NAVIGATE', 'did-navigate')
    //console.log('did-navigate')
  }
})

